Version 1.12
------------

- Added ``DummyReward`` for only sampling from a base model.
- Added ``xt`` and ``t`` arguments to ``BaseModel.train_loss``.
- Added rewards for more quantum chemistry properties returned by GFN2-xTB.
